@@ -9,7 +9,7 @@
       $('.paypal-bml-popin-text').hide();
       $('.paypal-bml-popin').click(function (event) {
         event.preventDefault();
-        $('.paypal-bml-popin-text').dialog({modal:true});
+        $('.paypal-bml-popin-text').dialog({modal:true, width: 550});
       });
     }
   };
